@@ -528,7 +528,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 35971671 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 36405693 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -1118,6 +1118,13 @@ cat /etc/passwd \
         append_silent "$DIR/.nv/nvidia-application-profile-globals-rc"
         append_silent "$DIR/.nv/nvidia-application-profile-globals-rc.backup"
         append_silent "$DIR/.nvidia-settings-rc"
+
+        for f in "$DIR/.config/vulkan/icd.d/*" \
+                 "$DIR/.config/vulkansc/icd.d/*" \
+                 "$DIR/.local/share/vulkan/icd.d/*" \
+                 "$DIR/.local/share/vulkansc/icd.d/*"; do
+            append_silent $f
+        done
     done
 
 # Capture global app profile configs
@@ -1157,12 +1164,13 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
         echo "Found Vulkan loader(s):"
         readlink -f ${vkinfo} 2> /dev/null
         echo ""
-        # See https://github.com/KhronosGroup/Vulkan-LoaderAndValidationLayers/blob/master/loader/LoaderAndLayerInterface.md
+        # See https://github.com/KhronosGroup/Vulkan-Loader/blob/main/docs/LoaderDriverInterface.md
         echo "Listing common ICD paths:"
         ls -d /usr/local/etc/vulkan/icd.d/* 2> /dev/null
         ls -d /usr/local/share/vulkan/icd.d/* 2> /dev/null
         ls -d /etc/vulkan/icd.d/* 2> /dev/null
         ls -d /usr/share/vulkan/icd.d/* 2> /dev/null
+        ls -d /etc/xdg/vulkan/icd.d 2> /dev/null
         echo ""
     else
         echo "Vulkan loader not found"
@@ -1170,6 +1178,32 @@ append_file_or_dir_silent /usr/share/nvidia/nvidia-application-profiles-*-rc
     fi
 ) | $GZIP_CMD >> $LOG_FILENAME
 
+# append Vulkan SC ICD info
+
+(
+    echo "____________________________________________"
+    echo ""
+
+    vkscinfo=`ldconfig -N -v -p 2> /dev/null | /bin/grep libvulkansc.so.1 | awk 'NF>1{print $NF}'`
+
+    if [ $? -eq 0 -a -n "$vkscinfo" ]; then
+        echo "Found Vulkan SC loader(s):"
+        readlink -f ${vkscinfo} 2> /dev/null
+        echo ""
+        # See https://github.com/KhronosGroup/VulkanSC-Loader/blob/main/docs/LoaderDriverInterface.md
+        echo "Listing common ICD paths:"
+        ls -d /usr/local/etc/vulkansc/icd.d/* 2> /dev/null
+        ls -d /usr/local/share/vulkansc/icd.d/* 2> /dev/null
+        ls -d /etc/vulkansc/icd.d/* 2> /dev/null
+        ls -d /usr/share/vulkansc/icd.d/* 2> /dev/null
+        ls -d /etc/xdg/vulkansc/icd.d 2> /dev/null
+        echo ""
+    else
+        echo "Vulkan SC loader not found"
+        echo ""
+    fi
+) | $GZIP_CMD >> $LOG_FILENAME
+
 # lspci information
 
 (
@@ -1818,7 +1852,18 @@ if [ $? -eq 0 -a -x "$systemctl" ]; then
         echo ""
     ) 2> /dev/null | $GZIP_CMD >> $LOG_FILENAME
 fi
-
+# get nvidia-imex-ctl output
+imexctl=`which nvidia-imex-ctl 2> /dev/null | head -n 1`
+if [ $? -eq 0 -a -x "$imexctl" ]; then
+    cmd="$imexctl -N"
+    (
+        echo "____________________________________________"
+        echo ""
+        echo "$cmd"
+        $cmd
+        echo ""
+    ) 2> /dev/null | $GZIP_CMD >> $LOG_FILENAME
+fi
 
 # Print information about the libglvnd libraries
 (
